@@ -489,7 +489,7 @@ SEXP medianFilter (SEXP _in, SEXP _r, SEXP _memsize) {
     for(j = 0; j < z; j++)
         ctmf(&px[framesize*j], &py[framesize*j], x, y, x, x, r, 1, memsize);
     
-    PROTECT( res = allocVector(REALSXP, imagesize) );
+    PROTECT( res = Rf_allocVector(REALSXP, imagesize) );
     DUPLICATE_ATTRIB(res, _in);
     
     // convert back to [0:1] range
